@@ -2,6 +2,8 @@
 #ifndef AKAXISO_CHOICE_H__
 #define AKAXISO_CHOICE_H__
 
+#include <typeinfo> /* {g++2.96} */
+
 #include <akaxiso/classes/qname.h>
 #include <akaxiso/classes/item.h>
 
@@ -35,6 +37,7 @@ namespace aka2 {
     virtual schematype_id get_schematype() const { return choice_id; }
     virtual const qname& get_typename() const { return L::typename_; }
     virtual const attribute_types* get_attribute_types() const { return 0; }
+    virtual const any_member *get_anyattr_type() const { return 0; }
     /** creatable */
     virtual void* create() const { return L::create(); }
     virtual void destroy(void *elm) const { L::destroy(elm); }
@@ -128,10 +131,10 @@ namespace aka2 {
 	        throw internal_error();
 	      itemtype_ = &res.first->second;
       }
-      void occurence(int minOccurs, int maxOccurs) {
+      void occurrence(int minOccurs, int maxOccurs) {
 	      schematype_id id = itemtype_->get_schematype();
 	      if ((id == array_id) || (id == choice_id)) 
-	        itemtype_->set_occurence(aka2::occurence(minOccurs, maxOccurs));
+	        itemtype_->set_occurrence(aka2::occurrence(minOccurs, maxOccurs));
 	      else
 	        throw internal_error();
       }
