@@ -5,9 +5,10 @@
 #include <akaxiso/classes/traits.h>
 
 namespace aka2 {
+
   void element_construct(void *e, const element_op& op);
 
-  void member_construct(void *e, const member_type &mtype);
+  void member_construct(void *e, const named_member &mtype);
   void item_construct(void *e, const itemtype &itype);
 
   void attributes_construct(void *e, const attribute_types *attrtypes);
