@@ -3,7 +3,6 @@
 #define AKAXISO_GLOBAL_ATTRIBUTES_H__
 
 #include <akaxiso/classes/namespaces.h>
-#include <string>
 
 namespace aka2 {
 
@@ -24,7 +23,7 @@ namespace aka2 {
     }
     // XML global attributes.
     // xsi:space will be stored.
-    
+
     //     const std::string &get_lang() const;
   private:
     // Namespace association
@@ -32,6 +31,6 @@ namespace aka2 {
     xmllang lang_;
   };
 
-}
+} // namespace aka2
 
-#endif
+#endif /* AKAXISO_GLOBAL_ATTRIBUTES_H__ */
