@@ -4,7 +4,7 @@
 
 #include <akaxiso/classes/types.h>
 #include <akaxiso/classes/document.h>
-#include <akaxiso/classes/attribute.h>
+#include <akaxiso/classes/membertype.h>
 #include <akaxiso/parser/handler.h>
 
 
