@@ -1,4 +1,4 @@
-// -*- c++ -*-
+/* -*- c++ -*- */
 #ifndef AKAXISO_HANDLER_H__
 #define AKAXISO_HANDLER_H__
 
@@ -12,7 +12,6 @@
 
 #include <stack>
 
-
 namespace aka2 {
 
   enum parse_result {
@@ -22,16 +21,18 @@ namespace aka2 {
   };
 
   struct handler;
+  typedef shared_ptr<handler> handler_ptr;
   class array_handler;
   class ptrmember_handler;
 
   struct parser_context {
-    typedef std::stack<handler*> handlers;
+    typedef std::stack<handler_ptr> handlers;
     parser_context() : 
       locator_(new locator()), source_name_("(not specified)"){}
+    ~parser_context() { delete locator_; }
 
-    void push(handler* h) { handlers_.push(h); }
-    handler* top() { return handlers_.top(); }
+    void push(handler* h) { handlers_.push(handler_ptr(h)); }
+    handler_ptr top() { return handlers_.top(); }
     void pop() { handlers_.pop(); }
     bool empty() const { return handlers_.empty(); }
 
@@ -46,7 +47,7 @@ namespace aka2 {
     }
     void raise_error(const std::string &message, 
 		     const char *filename, const unsigned long linenum);
-    void report_wrong_occurence(const std::string &message, const occurence &occ, int actual);
+    void report_wrong_occurrence(const std::string &message, const occurrence &occ, int actual);
   private:
     handlers handlers_;
     const locator *locator_;
@@ -54,8 +55,6 @@ namespace aka2 {
   };
 
 
-
-
   struct handler {
     virtual ~handler(){}
     virtual parse_result query_element(const qname &tagname, const attribute_values &attrs, 
@@ -78,20 +77,20 @@ namespace aka2 {
 				 const global_attributes &gattrs);
 
     handler* create_particle_handler(const qname &tagname, void *e, const element_op &op,
-				     int depth, const occurence &occ);
+				     int depth, const occurrence &occ);
     handler* create_element_handler(const qname &tagname, void *e, const element_op &op,
-				    int depth, const occurence &occ);
+				    int depth, const occurrence &occ);
     array_handler* create_array_handler(const qname &tagname, void *e, const array_op &op,
-					int depth, const occurence &occ, bool is_element);
+					int depth, const occurrence &occ, bool is_element);
     ptrmember_handler* create_ptrmember_handler(const qname &tagname, void *e, 
 						const ptrmember_op &op,
-						int depth, const occurence &occ, bool is_element);
+						int depth, const occurrence &occ, bool is_element);
     handler *create_fixed_handler(const qname &tagname, int depth, const member_type &mtype);
     handler *create_fixed_array_handler(const qname &tagname, int depth, const member_type &mtype);
 
 
     static handler *create_root_handler(const qname &tagname, void *e, const element_op &op,
-					const occurence &occ, 
+					const occurrence &occ, 
 					parser_context &context);
 
  protected:
@@ -101,7 +100,7 @@ namespace aka2 {
       context_(h.context_), depth_(depth), tagname_(tagname){}
 
     static handler* create_handler(const qname &tagname, void *e, const element_op &op,
-				   int depth, const occurence &occ, 
+				   int depth, const occurrence &occ, 
 				   parser_context &context);
 
     parser_context &context_;
@@ -109,8 +108,6 @@ namespace aka2 {
     const qname tagname_;
   };
 
-}
+} // namespace aka2
 
-
-
-#endif
+#endif /* AKAXISO_HANDLER_H__ */
