@@ -89,14 +89,14 @@ parse_result sequence_handler::parse_element(const qname &tagname,
   case choice_id:
   case all_id: {
     create_particle_handler(tagname, memelm, *memberop, depth_ + 1, 
-			    it_->get_occurence());
+			    it_->get_occurrence());
     break;
   }
   case simpletype_id:
   case simplecontent_id: {
     it_->set_member_to_default(seq_);
     create_element_handler(tagname, memelm, *memberop, 
-			   depth_ + 1, it_->get_occurence());
+			   depth_ + 1, it_->get_occurrence());
     break;
   }
   case fixed_id: {
@@ -108,7 +108,7 @@ parse_result sequence_handler::parse_element(const qname &tagname,
   case array_id: {
     handler *h = create_array_handler(tagname, memelm, 
 				      static_cast<const array_op&>(*memberop), 
-				      depth_, it_->get_occurence(), true);
+				      depth_, it_->get_occurrence(), true);
     parse_result res = h->query_element(tagname, attrs, gattrs);
     assert(res == ok);
     break;
@@ -116,7 +116,7 @@ parse_result sequence_handler::parse_element(const qname &tagname,
   case ptrmember_id: {
     handler *h = create_ptrmember_handler(tagname, memelm, 
 					  static_cast<const ptrmember_op&>(*memberop),
-					  depth_, it_->get_occurence(), true);
+					  depth_, it_->get_occurrence(), true);
     parse_result res = h->query_element(tagname, attrs, gattrs);
     assert(res == ok);
     break;
@@ -153,19 +153,19 @@ parse_result sequence_handler::find_particle(const qname &tagname,
   case sequence_id:
   case choice_id: {
     current = create_particle_handler(tagname, memelm, memberop, 
-				      depth_, it_->get_occurence());
+				      depth_, it_->get_occurrence());
     break;
   }
   case array_id: {
     current = create_array_handler(tagname, memelm, 
 				   static_cast<const array_op&>(memberop), 
-				   depth_, it_->get_occurence(), false);
+				   depth_, it_->get_occurrence(), false);
     break;
   }
   case ptrmember_id: {
     current = create_ptrmember_handler(tagname, memelm, 
 				       static_cast<const ptrmember_op&>(memberop)
-				       , depth_, it_->get_occurence(), false);
+				       , depth_, it_->get_occurrence(), false);
     break;
   }
   case all_id: // All could not be in nested particles/groups.
@@ -183,16 +183,13 @@ parse_result sequence_handler::find_particle(const qname &tagname,
   if (res == ok)
     return ok;  // Element given by tagname found.
 
-  handler *to_delete;
   // Rollup.
-  while (context_.top() != current) {
-    to_delete = context_.top();
-    delete to_delete;
-  }
+  while (context_.top() != current)
+    context_.pop();
+
   // Remove current.
-  assert(current == context_.top());
-  to_delete = context_.top();
-  delete to_delete;
+  assert(context_.top() == current);
+  context_.pop();
 
   assert((res == skip) || (res == error));
   return res; // skip or error.
@@ -247,7 +244,7 @@ bool sequence_handler::can_skip_member() {
   switch (memberop.get_schematype()) {
   case array_id: 
   case ptrmember_id: {
-    return it_->get_occurence().in_range(0);
+    return it_->get_occurrence().in_range(0);
   }
   case fixed_id: 
   case sequence_id:
@@ -255,7 +252,7 @@ bool sequence_handler::can_skip_member() {
     if (it_->is_element())
       return false;
     current = create_particle_handler(qname(), memelm, mpair.op_, depth_, 
-				      it_->get_occurence());
+				      it_->get_occurrence());
     break;
   }
   case simpletype_id:
@@ -271,10 +268,7 @@ bool sequence_handler::can_skip_member() {
 
   assert(context_.top() == current);
   bool ok_to_skip = current->can_skip();
-
   context_.pop();
-  delete current;
-
   return ok_to_skip;
 }
 
