@@ -1,6 +1,7 @@
 #include "basket.h"
-#include <akaxiso/akaxiso.h>
 
+#include <akaxiso/akaxiso.h>
+#include <iostream>
 #include <stdlib.h>
 
 void serialize() {
@@ -60,7 +61,7 @@ void parse() {
     else if (aka::item_of(*it, "egg")) {
       eggs & es = aka::item_cast<eggs>(*it);
       for (eggs::const_iterator it = es.begin(); it != es.end(); ++it)
-	std::cout << "egg(" << it->weight_ << "g)" << std::endl;
+        std::cout << "egg(" << it->weight_ << "g)" << std::endl;
     }
   }
 }
@@ -68,23 +69,19 @@ void parse() {
 
 void usage() {
   std::cout << "project [-s|-p|-h]" << std::endl
-	    << "  -s : serialize." << std::endl
-	    << "  -p : parse.    " << std::endl
-	    << "  -h : show this usage." << std::endl;
+            << "  -s : serialize." << std::endl
+            << "  -p : parse.    " << std::endl
+            << "  -h : show this usage." << std::endl;
 }
 
 
 int main(int argc, const char* argv[]){
   
-  // Initialize Xerces.
-#ifdef USE_XERCESC
-  xercesc::XMLPlatformUtils::Initialize();
-#endif
   aka::initialize();
 
   // Initialize document.
   aka::doctype("basket", xiso::leaf<basket>(), 
-	       aka::occurence(0, aka::unbounded));
+               aka::occurrence(0, aka::unbounded));
 
   if (argc != 2) {
     usage();
@@ -103,8 +100,5 @@ int main(int argc, const char* argv[]){
   }
 
   aka::uninitialize();
-#ifdef USE_XERCESC
-  xercesc::XMLPlatformUtils::Terminate();
-#endif
   return 0;
 }
