@@ -3,7 +3,6 @@
 #define BASKET_H__
 
 #include <akaxiso/content_model.h>
-
 #include <list>
 
 struct basket : std::list<aka::item> {};
@@ -40,7 +39,7 @@ namespace xiso {
     void model() {
       item("fruit", fruit_leaf());
       item("vesitable", vesitable_leaf());
-      item("egg", leaf<eggs>()).occurence(0, aka::unbounded);
+      item("egg", leaf<eggs>()).occurrence(0, aka::unbounded);
     }
   };
 
