@@ -5,6 +5,7 @@
 #include "model_array.h"
 
 #include <akaxiso/akaxiso.h>
+#include <iostream>
 #include <stdlib.h>
 
 void parse() {
@@ -45,16 +46,12 @@ void parse() {
 
 void usage() {
   std::cout << "project [-h]" << std::endl
-	    << "  -h : show this usage." << std::endl;
+            << "  -h : show this usage." << std::endl;
 }
 
 
 int main(int argc, const char* argv[]){
-  
-  // Initialize Xerces.
-#ifdef USE_XERCESC
-  xercesc::XMLPlatformUtils::Initialize();
-#endif
+
   aka::initialize();
 
   // Initialize Project classes defined in project.h.
@@ -65,7 +62,7 @@ int main(int argc, const char* argv[]){
   aka::doctype("cuppa:sequence_map", pj::OrderedSequenceTeamLeaf());
 
   aka::doctype("basket", xiso::leaf<basket>(), 
-	       aka::occurence(0, aka::unbounded));
+               aka::occurrence(0, aka::unbounded));
 
   aka::doctype("params", xiso::leaf<params>());
 
@@ -74,8 +71,5 @@ int main(int argc, const char* argv[]){
   parse();
 
   aka::uninitialize();
-#ifdef USE_XERCESC
-  xercesc::XMLPlatformUtils::Terminate();
-#endif
   return 0;
 }
