@@ -2,8 +2,8 @@
 #ifndef PROJECT_H__
 #define PROJECT_H__
 
-#include <list>
 #include <akaxiso/content_model.h>
+#include <list>
 
 namespace pj {
 
@@ -44,7 +44,7 @@ namespace xiso {
       member("cuppa:project_name", &pj::Team::name_);
       member("cuppa:url", &pj::Team::url_);
       enclose("cuppa:members");
-      ; member("cuppa:member", &pj::Team::members_).occurence(0, aka::unbounded);
+      ; member("cuppa:member", &pj::Team::members_).occurrence(0, aka::unbounded);
       disclose("cuppa:members");
     }
   };
