@@ -64,7 +64,7 @@ namespace xs {
   void define_schemadoc();
   void serialize(const aka::document &doc);
 
-  inline bool is_array(const aka::occurence &occ) {
+  inline bool is_array(const aka::occurrence &occ) {
     return (occ.minOccurs_ != 1) || (occ.maxOccurs_ != 1);
   }
 
