@@ -3,10 +3,6 @@
 #include <iostream>
 
 int main(int argc, char* argv[]){
-
-#ifdef USE_XERCESC
-  xercesc::XMLPlatformUtils::Initialize();
-#endif
   
   // Initialize Xerces.
   aka::initialize();
