@@ -50,7 +50,7 @@ namespace xiso {
 }
 
 inline void instantiate_xiso() {
-  aka::doctype("janken", xiso::leaf<janken_choice>(), aka::occurence(0, aka::unbounded));
+  aka::doctype("janken", xiso::leaf<janken_choice>(), aka::occurrence(0, aka::unbounded));
 }
 
 #endif
