@@ -552,16 +552,16 @@ class ygg_node_body :public ygg_smart_base {
   friend class ygg_node;
 
   protected:
-  ygg_root  *parent;
+  ygg_node_body  *parent;
 
   ygg_node_body() :parent(NULL) {}
   virtual ~ygg_node_body() { }
 
-    ygg_node & get_parent() {
-      return *((ygg_node *)&parent);
+    ygg_node  get_parent() {
+      return ygg_node(parent);
     }
-    const ygg_node & get_parent() const {
-      return *((ygg_node *)&parent);
+    ygg_node  get_parent() const {
+      return ygg_node(parent);
     }
 virtual bool is_live() const = 0;
 virtual ygg_string get_type() const = 0;
@@ -593,10 +593,10 @@ virtual void exile_node(ygg_node X);
 virtual ygg_node clone() const = 0;
 
     ygg_node get_shell() {
-      return this;
+      return ygg_node(this);
     }
-    const ygg_node get_shell() const {
-      return (ygg_node_body*)this;
+    ygg_node get_shell() const {
+      return ygg_node(const_cast<ygg_node_body*>(this));
     }
 
 #ifdef _DEBUG
@@ -795,7 +795,7 @@ class ygg_ghost :public ygg_node_body {
   ygg_string path;
 
   protected:
-  ygg_ghost(ygg_root *X_parent, const ygg_string &X_path) {
+  ygg_ghost(ygg_node_body *X_parent, const ygg_string &X_path) {
     parent = X_parent;
     path = X_path;
   }
@@ -831,7 +831,7 @@ class ygg_ghost :public ygg_node_body {
 
   public:
 static
-  ygg_node create(ygg_root *X_parent, const ygg_string &X_path) {
+  ygg_node create(ygg_node_body *X_parent, const ygg_string &X_path) {
     return new ygg_ghost(X_parent, X_path);
   }
 };
@@ -1398,7 +1398,7 @@ static
   }
 };
 inline void ygg_node_body::regist_parent(ygg_root *X) {
-  assert(("̃m[hɂ͊ɐe܂B 'em[h.exile_node(̃m[h)' Ő≏邩A'̃m[h.close()' ŃN[쐬ĂB", NULL == parent));
+  assert(("̃m[hɂ͊ɐe܂B 'em[h.exile_node(̃m[h)' Ő≏邩A'̃m[h.close()' ŃN[쐬ĂB" && (NULL == parent)));
   if (NULL != this && ygg_node_type::empty != get_type()) {
     parent = X;
     X->adopt_child(this);
@@ -1630,6 +1630,7 @@ class sax_handler {
   protected:
   ygg_parser * get_parser();
   public:
+  virtual ~sax_handler(){}
   virtual void on_error(ygg_error* parse_error);  //  parse_error->clear() 
   virtual void start_document(ygg_node root);   //  Rgm[h̕t̂ 
   virtual void end_document(ygg_node &root);    //  root.vanish() сȂ̑S 
@@ -1644,6 +1645,7 @@ class sax_handler {
 class error_catcher :public sax_handler {
   public:
   ygg_error parse_error;
+  virtual ~error_catcher(){}
   void on_error(ygg_error* X_parse_error) {
     this->parse_error = *X_parse_error;
   }
@@ -1750,7 +1752,7 @@ inline sox_parser & sox_parser::read(std::istream &stream) {
       stream.read(first_buffer, 4096);
       second_buffer.assign(first_buffer, stream.gcount());
 
-      const int determine_encoding = (babel::base_encoding::unknown == encoding) ? analyze_base_encoding(second_buffer): encoding;
+      const int determine_encoding = (babel::base_encoding::unknown == encoding) ? analyze_base_encoding(second_buffer).operator const int&(): encoding;
       bbl_translater<bbl_binary, ygg_string> translater = manual_translate_engine<bbl_binary, ygg_string>::order(determine_encoding);
 
       while(true) {
@@ -1943,6 +1945,7 @@ inline int get_encoding_from_label(const char *label) {
     0 == stricmp(label, "utf16be")) {
     return utf16be;
   }
+#ifdef __BBL_USE_UTF32__
   if (0 == stricmp(label, "utf-32") ||
     0 == stricmp(label, "utf32")) {
     return utf32;
@@ -1955,6 +1958,7 @@ inline int get_encoding_from_label(const char *label) {
     0 == stricmp(label, "utf32be")) {
     return utf32be;
   }
+#endif
   return unknown;
 }
 inline babel::bbl_translater<babel::bbl_binary, ygg_string> get_translater(const ygg_string &header) {
